Function to sample from the model X= AX + B with X = (eta + lambda X) Z^2, Z iid Gaussian. For the default values, this model has index of regular variation alpha = 1 and extremal index theta = 0.727
Examples
path <- ARCH2m(1000)
plot.ts(path)
Function to sample from the model X= AX + B with X = (eta + lambda X) Z^2, Z iid Gaussian. For the default values, this model has index of regular variation alpha = 1 and extremal index theta = 0.727
path <- ARCH2m(1000)
plot.ts(path)