Function to sample from the model X = AX + B with log A ~ N-0.5, B ~ Unif(0,1) The model has index of regular variation alpha = 1 and extremal index theta = 0.2792
Examples
path <- ARCHm(1000)
plot.ts(path)
Function to sample from the model X = AX + B with log A ~ N-0.5, B ~ Unif(0,1) The model has index of regular variation alpha = 1 and extremal index theta = 0.2792
path <- ARCHm(1000)
plot.ts(path)