Skip to contents

Function to sample from the model X = (par0)X + Z. For the default values, this model has index of regular variation alpha identical to Z and extremal index 1-(par0)^alpha

Usage

ARm(n0, par0 = 0.7, Z.gen = function(n) rt(n, df = 1))

Arguments

n0

(Integer with trajectory length)

par0

(Value in (0,1))

Z.gen

(Function of a trajectory length n to sample from the noise)

Value

(Vector of length n0 sampled from the SRE model)

Examples

path  <- ARm(1000,0.7)
plot.ts(path)