This function computes the (tail)-index. It returns the mean estimate from the Pickands, Hill and DeHaan estimators at 96th empirical quantile. It uses the fExtreme code.
This function computes the (tail)-index. It returns the mean estimate from the Pickands, Hill and DeHaan estimators at 96th empirical quantile. It uses the fExtreme code.