Skip to contents

Estimates of the cluster statistics and based on the alpha cluster Process

Usage

functionalCP(
  path0,
  alpha0,
  klim0 = 100,
  n0 = length(path0),
  p0 = "alpha",
  cluster_func = function(block) max(abs(block)^alpha0),
  plot = F
)

Arguments

path0

(Matrix with the sample trajectory of a time series)

alpha0

(Integer with an estimate of the tail index)

klim0

(Integer with the largest order statistic k to consider, or a vector with values k to consider)

n0

(Integer with the path length)

cluster_func

(A function to evaluate on extremal blocks. As a default we provide the functional for computing the extremal index)

plot

(F or T if the plot with estimates as a function of k must be shown)

Value

data frame with estimates of the the cluster functional estimates values of k and block lengths b used for inference An estimate of the asymptotic variance is also provided using cluster process inference.

Examples

path  <- ARCHm(20000)
alpha <- 1/alphaestimator(path,k1=1200)$xi ## The real value should be one
ei    <- functionalCP(path,1,plot=T)       ## two options are available for computing the extremal index
#> Error in cluster_func(path0[((l - 1) * b0 + 1):(l * b0)]/suma_p[l], p0,     alpha0): unused arguments (p0, alpha0)
ei2   <- eiCP(path,1,plot=T)