Skip to contents

This function computes Hill (tail)-index estimate of a stationary time series.

Usage

hillestimator(path, k1 = NULL, plot = F)

Arguments

path

(vector of univariate observations)

k1

(vector of order statistics to compute Hill estimates). It uses k1 = n*0.05 otherwise

plot

(T or F if a plot should be shown).

Value

A data.frame of hill estimates as a function of k.

Examples

h <- hillestimator(rainfall$LANVEOC[rainfall$SEASON=='SPRING'], 1:200)
h <- hillestimator(rainfall$LANVEOC[rainfall$SEASON=='SPRING'], plot=T)