Empirical temporal extremogram
Arguments
- sample
A numerical vector to compute the extremogram
- maxlag
An integer with the
- q
A quantile level in (0,1).
- plot
A logical value to plot the results
Details
The temporal extremogram \(\chi_t\) is defined by $$\chi_t = \lim_{t \to \infty} \mathbb{P}( X_t > x | X_0 > x).$$ Its empirical version, computes the average number of exceedances of the q-th order statistic. As a baseline, the extremogram takes the value of 1-q at independent lags.
Examples
pre <- tsExtremes::rainfall ## load rainfall data
sample <- na.omit(sample) ## removes columns with missing values
sample <- tsExtremes::rmax(pre[pre$SEASON=='FALL' , 5:7]) ## computes vector-wise maxima
tsExtremes::extremogram(sample)
#> Error in tsExtremes::extremogram(sample): object 'n' not found