Estimates of the cluster legths and the extrema index based on the alpha cluster Process
Usage
piCP(path0, alpha0, klim0 = 100, n0 = length(path0), plot = F)Arguments
- path0
(Matrix with the sample trajectory of a time series)
- alpha0
(Integer with an estimate of the tail index)
- klim0
(Integer with the largest order statistic k to consider, or a vector with values k to consider)
- n0
(Integer with the path length)
- plot
(F or T if the plot with estimates as a function of k must be shown)
Value
data frame with estimates of the the cluster lengths pi_j with values of k and block lengths b used for inference An estimate of the asymptotic variance is also provided using cluster process inference.
Examples
path <- ARCHm(20000)
alpha <- 1/alphaestimator(path,k1=1200)$xi ## The real value should be one
pi <- piCP(path,alpha,plot=T)